/**
 * An accordion that allows you to expand and collapse content
 * */
export default {
  title: 'Components/Accordion',
  tags: ['autodocs'],
  argTypes: {
    expanded: {
      control: 'boolean',
    },
  },
  args: {
    expanded: false,
  },
}

const AccordionTemplate = ({ expanded }) => {
  return`
    <details class="rpf-accordion" ${expanded ? 'open' : ''}>
      <summary class="rpf-accordion__title">
        What is an accordion?
        <span class="rpf-accordion__icon"></span>
      </summary>
      <p class="rpf-accordion__text">An accordion is a musical instrument that has keys similar to a piano, but is small enough for a person to hold. It makes sounds using air pushed and pulled through reeds using a bellows. The accordion can also have buttons instead of keys.</p>
    </details>`
}

export const Default = AccordionTemplate.bind({})
Default.args = {}

export const Expanded = AccordionTemplate.bind({})
Expanded.args = {
  expanded: true,
}

const MultipleAccordionTemplate = () => {
  return`
    <details class="rpf-accordion">
      <summary class="rpf-accordion__title">
        What is an accordion?
        <span class="rpf-accordion__icon"></span>
      </summary>
      <p class="rpf-accordion__text">An accordion is a musical instrument that has keys similar to a piano, but is small enough for a person to hold. It makes sounds using air pushed and pulled through reeds using a bellows. The accordion can also have buttons instead of keys.</p>
    </details>
    <details class="rpf-accordion">
      <summary class="rpf-accordion__title">
        What is a concertina?
        <span class="rpf-accordion__icon"></span>
      </summary>
      <p class="rpf-accordion__text">A concertina is a musical instrument that makes sounds using air pushed and pulled through reeds using a bellows. The fingers push buttons at both ends of the instrument.</p>
    </details>`
}

export const Multiple = MultipleAccordionTemplate.bind({})

/*
 * Accordion with container.  This is an older layout
 */

const AccordionWithContainerTemplate = () => {
  return`
    <div class="rpf-accordion">
      <details class="rpf-accordion__container">
        <summary class="rpf-accordion__title">
          What is an accordion?
          <span class="rpf-accordion__icon"></span>
        </summary>
        <p class="rpf-accordion__text">An accordion is a musical instrument that has keys similar to a piano, but is small enough for a person to hold. It makes sounds using air pushed and pulled through reeds using a bellows. The accordion can also have buttons instead of keys.</p>
      </details>
      <details class="rpf-accordion__container">
        <summary class="rpf-accordion__title">
          What is a concertina?
          <span class="rpf-accordion__icon"></span>
        </summary>
        <p class="rpf-accordion__text">A concertina is a musical instrument that makes sounds using air pushed and pulled through reeds using a bellows. The fingers push buttons at both ends of the instrument.</p>
      </details>
    </div>`
}

export const AccordionWithContainer = AccordionWithContainerTemplate.bind({})
