/**
 * A symetrical squiggly line to be used as a horizontal rule or under a heading.
 *
 * The color of the squiggle can be changed by setting the `--rpf-squiggle-color` CSS property. This can be set on the `hr` or `h1/h2/etc` directly, or an any parent element. It will otherwise default to `--rpf-brand-raspberry`.
 */

export default {
  title: 'Components/Squiggle',
  tags: ['autodocs'],
  argTypes: {
    color: {
      control: 'string',
    },
  },
  args: {
    color: null,
  },
}

const Template = ({ color }) => {
  if (color) {
    return `<hr class="rpf-squiggle" style="--rpf-squiggle-color: ${color}" />`
  }
  return `<hr class="rpf-squiggle" />`
}

export const Hr = Template.bind({})
Hr.args = {}

export const CustomColor = Template.bind({})
CustomColor.args = {
  color: 'var(--rpf-brand-leaf)'
}

const HeadingTemplate = ({ color }) => {
  if (color) {
    return `<h1 class="rpf-squiggle-heading" style="--rpf-squiggle-color: ${color}">Some text</h1>`
  }
  return `<h1 class="rpf-squiggle-heading">Some text</h1>`
}

export const Heading = HeadingTemplate.bind({})
Heading.args = {}

export const HeadingWithCustomColor = HeadingTemplate.bind({})
HeadingWithCustomColor.args = {
  color: 'var(--rpf-brand-leaf)'
}
