import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/input-number.scss'
import '../../scss/components/forms/error-message.scss'

export default {
  title: 'Components/Form/NumberInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const NumberTemplate = ({ disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_number = classNames('rpf-input rpf-input-number', {
    'rpf-input--error': error,
    'rpf-input--disabled': disabled,
    'rpf-input--full-width': fullWidth,
    'rpf-input--readonly': readonly,
  })

  return `
    <div class="${classnames_wrapper}">
      <div class="${classnames_label}">
        <label for="apple_quantity">How many apples do you need?</label>
        <div class="rpf-label__hint">Please the total number</div>
      </div>
      <div class="${classnames_number}">
      <input type="number" id="apple_quantity" name="quantity"${disabled ? ' disabled' : ''}${
    readonly ? ' readonly' : ''
  } value="0">
      <button tabindex="-1" aria-hidden="true" class="rpf-button rpf-button--sm rpf-button--tertiary rpf-button--icon-only" onclick="this.parentNode.querySelector('#apple_quantity').stepDown()">
        <span class="rpf-button__icon material-symbols-sharp">
          remove
        </span>
      </button>
      <hr aria-hidden="true"/>
      <button tabindex="-1" aria-hidden="true" class="rpf-button rpf-button--sm rpf-button--tertiary rpf-button--icon-only" onclick="this.parentNode.querySelector('#apple_quantity').stepUp()">
        <span class="rpf-button__icon material-symbols-sharp">
          add
        </span>
      </button>

      </div>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: It must be more than zero</div>'
          : ''
      }
  </div>
    </div>
  `
}

export const Default = NumberTemplate.bind({})
Default.args = {}

export const Error = NumberTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = NumberTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = NumberTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const FullWidth = NumberTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}
